@@ -16,13 +16,12 @@ pub mod tcp;
 pub mod udp;
 
 mod client;
+mod header;
 mod message_table;
 mod server;
 
-extern crate carrier_pigeon_netmsg_derive;
-
-pub use carrier_pigeon_netmsg_derive::NetMsg;
 pub use client::Client;
-pub use message_table::{MsgTable, MsgTableParts, SortedMsgTable};
-pub use net::{CId, MId, NetError, NetMsg, Transport};
+pub use header::Header;
+pub use message_table::{MsgRegError, MsgTable, MsgTableParts, SortedMsgTable};
+pub use net::{CId, MId, NetError, Transport};
 pub use server::Server;
